@@ -8,27 +8,24 @@
 
 using namespace Akonadi;
 
-class Akonadi::MessageFolderAttribute::Private
+class Akonadi::MessageFolderAttributePrivate
 {
 public:
     bool isOutboundFolder = false;
 };
 
 MessageFolderAttribute::MessageFolderAttribute()
-    : d(new Private)
+    : d(new MessageFolderAttributePrivate)
 {
 }
 
 MessageFolderAttribute::MessageFolderAttribute(const MessageFolderAttribute &other)
     : Attribute(other)
-    , d(new Private(*(other.d)))
+    , d(new MessageFolderAttributePrivate(*(other.d)))
 {
 }
 
-MessageFolderAttribute::~MessageFolderAttribute()
-{
-    delete d;
-}
+MessageFolderAttribute::~MessageFolderAttribute() = default;
 
 QByteArray MessageFolderAttribute::type() const
 {
